@@ -104,8 +104,8 @@ class ImportProgressPage(WizardProgressPage):
     def __init__(self, owner):
         WizardProgressPage.__init__(self, owner, "Import Data")
 
-        self.add_task(self.prepare_import, "Prepare Import")
-        self.add_threaded_task(self.start_import, "Import data file")
+        self.add_task(self.prepare_import, "Prepare Import", "Prepare Import")
+        self.add_threaded_task(self.start_import, "Import data file", "Import Data Dile")
         self.module = None
         self.stop = None
         self.import_time = None
@@ -193,6 +193,7 @@ class ConfigurationPage(WizardPage):
         format_box.add(mforms.newLabel("Detected file format: %s" % self.input_file_type), False, True)
         if len(self.active_module.options) != 0:
             advanced_opts_btn = mforms.newButton(mforms.ToolButton)
+            advanced_opts_btn.set_size(-1, 16)
             advanced_opts_btn.set_icon(mforms.App.get().get_resource_path("admin_option_file.png"))
             advanced_opts_btn.add_clicked_callback(lambda: self.optpanel.show(False) if self.optpanel.is_shown() else self.optpanel.show(True) )
             format_box.add(advanced_opts_btn, False, True)
@@ -760,6 +761,7 @@ class SelectFileWizardPage(WizardPage):
 
         self.importfile_browse_btn = mforms.newButton()
         self.importfile_browse_btn.set_text("Browse...")
+        self.importfile_browse_btn.set_name("Browse")
         self.importfile_browse_btn.add_clicked_callback(self.importfile_browse)
         entry_box.add(self.importfile_browse_btn, False, False)
 
