@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
+#
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-# 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import functools
 
@@ -85,7 +89,7 @@ class DatabaseSchemaSelector(mforms.Box):
                          },
             'schemas'  : { 'icon': 'db.Schema.16x16.png',
                          },
-            'general'  : { 'summary_text': '%(nSchemata)d schemata selected',
+            'general'  : { 'summary_text': '%(nSchemata)d schemas selected',
                            'show_select_all_button': not self.use_catalogs,
                            'show_unselect_all_button': True,
                          },
@@ -113,6 +117,7 @@ class DatabaseSchemaSelector(mforms.Box):
         self.set_spacing(8)
         
         self.schema_list_tree = mforms.newTreeView(mforms.TreeDefault)
+        self.schema_list_tree.set_name('Schema List')
         self.schema_list_tree.add_column(mforms.CheckColumnType, 'Include', 60, True)
         self.schema_list_tree.add_column(mforms.IconColumnType, 'Catalog/Schema' if self.use_catalogs else 'Schema', 300, False)
         self.schema_list_tree.end_columns()
@@ -124,6 +129,7 @@ class DatabaseSchemaSelector(mforms.Box):
         helper_buttons_box.set_spacing(12)
 
         self.select_summary_label = mforms.newLabel('')
+        self.select_summary_label.set_name('Summary')
         helper_buttons_box.add(self.select_summary_label, False, True)
 
         if self.ui_settings['general']['show_unselect_all_button']:
